@@ -104,7 +104,11 @@
 #   undef BLASSCALAR
 #endif
 #if defined(PRIMME_BLAS_RCOMPLEX)
+#   ifndef USE_FC_LEN_T
+#       define USE_FC_LEN_T
+#   endif
 #   ifndef CHECK_TEMPLATE
+#       include <Rconfig.h>
 #       include <R_ext/BLAS.h>
 #   endif
 #   ifdef USE_FC_LEN_T
