@@ -35,11 +35,15 @@
  *
  ******************************************************************************/
 
+#ifndef USE_FC_LEN_T
+#    define USE_FC_LEN_T
+#endif
 #include <R.h>
 #include <Rcpp.h>
 #include <algorithm>
 #include "primme.h"
 #include "PRIMME_types.h"
+#include <Rconfig.h>
 #include <R_ext/BLAS.h> // for BLAS and F77_NAME
 
 #include "Matrix.h"
